pub struct ClockAbsenceDetector<'a, 'd, T>where
T: Instance,{ /* private fields */ }Expand description
Clock-absence detector.
Implementations
Sourceimpl<'a, 'd, T> ClockAbsenceDetector<'a, 'd, T>
impl<'a, 'd, T> ClockAbsenceDetector<'a, 'd, T>
Sourcepub async fn wait_for_event(&mut self) -> u8
pub async fn wait_for_event(&mut self) -> u8
Wait for a clock-absence-detector event
Sourceimpl<'a, 'd, T> ClockAbsenceDetector<'a, 'd, T>where
T: Instance,
impl<'a, 'd, T> ClockAbsenceDetector<'a, 'd, T>where
T: Instance,
Sourcepub fn assign_transceivers<const N: usize>(
&mut self,
transceivers: [&dyn TransceiverTrait<T, Enabled>; N],
)
pub fn assign_transceivers<const N: usize>( &mut self, transceivers: [&dyn TransceiverTrait<T, Enabled>; N], )
Assigns the transceivers to the clock-absence-detector (overwrites assignments)
Sourcepub fn unassign_transceivers<const N: usize>(
&mut self,
transceivers: [&dyn TransceiverTrait<T, Enabled>; N],
)
pub fn unassign_transceivers<const N: usize>( &mut self, transceivers: [&dyn TransceiverTrait<T, Enabled>; N], )
Unassigns the transceivers from the clock-absence-detector
Sourcepub fn channel_flag(&self, channel: TransceiverChannel) -> bool
pub fn channel_flag(&self, channel: TransceiverChannel) -> bool
Whether the clock-absence flag is set for channel.
Sourcepub fn clear_channel_flags(&mut self, channel: TransceiverChannel)
pub fn clear_channel_flags(&mut self, channel: TransceiverChannel)
Clear the clock-absence flag for channel.
Sourcepub fn flags(&self) -> u8
pub fn flags(&self) -> u8
Clock-absence flag bitmap.
Note
The raw CKABF bits are held set while a channel is disabled or not yet
synchronized, so they are masked here against the armed channel set.
Call clear_flags after assigning transceivers to
drop startup residue.
Sourcepub fn clear_flags(&mut self)
pub fn clear_flags(&mut self)
Clear all pending detector flags for currently armed channels.
Use this after assigning transceivers to clear any startup residue before waiting for events.